@@ -5,6 +5,7 @@ import datetime as dt
 import json
 import copy
 import uuid
+import types
 
 from marshmallow import base, fields, utils
 from marshmallow.compat import (with_metaclass, iteritems, text_type,
@@ -100,7 +101,10 @@ class BaseSerializer(base.SerializerABC):
     def __init__(self, obj=None, extra=None, only=None,
                 exclude=None, prefix='', strict=False):
         self.opts = SerializerOpts(self.Meta)
-        self.obj = obj
+        if isinstance(obj, types.GeneratorType):
+            self.obj = list(obj)
+        else:
+            self.obj = obj
         self.only = only or ()
         self.exclude = exclude or ()
         self.prefix = prefix
@@ -183,10 +187,10 @@ class BaseSerializer(base.SerializerABC):
         if not isinstance(self.opts.fields, (list, tuple)):
             raise ValueError("`fields` option must be a list or tuple.")
         obj_marshallable = utils.to_marshallable_type(self.obj)
-        if isinstance(obj_marshallable, (list, tuple)):  # Homogeneous list
-            if len(obj_marshallable) > 0:
+        if utils.is_collection(obj_marshallable):  # Homogeneous collection
+            try:
                 obj_dict = utils.to_marshallable_type(obj_marshallable[0])
-            else:  # Nothing to serialize
+            except IndexError:  # Nothing to serialize
                 return declared_fields
         else:
             obj_dict = obj_marshallable
